from setuptools import setup

setup(name='distributionsGB',
      version='0.1',
      description='Gaussian and binomial distributions',
      packages=['distributionsGB'],
      author = 'Carolina Negrelli',
      author_email = 'caro.negrelli@gmail.com',
      zip_safe=False)
